@@ -21,6 +21,10 @@ export * from './options'
 export * from './pool'
 export * from './route'
 export * from './storage'
+export * from './storageDomains'
+export * from './dataCenters'
+export * from './pendingTasks'
+export * from './vnicProfiles'
 
 export function schedulerOneMinute () {
   return {
@@ -37,6 +41,9 @@ export function persistState () {
   }
 }
 
+/**
+ * Not creator of an action. Returned object can't be dispatched to the store.
+ */
 export function getSingleVm ({ vmId }) {
   return {
     type: GET_VM,
