@@ -24,6 +24,7 @@ import FieldHelp from '../FieldHelp/index'
 import DetailContainer from '../DetailContainer'
 import ConsoleOptions from '../ConsoleOptions/index'
 import VmDisks from '../VmDisks/index'
+import VmNics from '../VmNics/index'
 import VmsListNavigation from '../VmsListNavigation/index'
 import VmStatus from './VmStatus'
 import { NextRunLabel } from './labels'
@@ -54,15 +55,18 @@ class VmDetail extends Component {
   constructor (props) {
     super(props)
     this.state = {
-      renderDisks: true,
       openConsoleSettings: false,
       vmsNavigationExpanded: true,
+      editDisks: false,
+      openNicSettings: false,
     }
 
     this.consoleSettings = this.consoleSettings.bind(this)
+    this.nicSettings = this.nicSettings.bind(this)
     this.toggleVmsNavExpansion = this.toggleVmsNavExpansion.bind(this)
     this.handleIconChange = this.handleIconChange.bind(this)
     this.handleIconChangeToDefault = this.handleIconChangeToDefault.bind(this)
+    this.editDisks = this.editDisks.bind(this)
   }
 
   toggleVmsNavExpansion (e) {
@@ -73,6 +77,11 @@ class VmDetail extends Component {
     e.preventDefault()
   }
 
+  editDisks (e) {
+    e.preventDefault()
+    this.setState({ editDisks: !this.state.editDisks })
+  }
+
   consoleSettings (e) {
     this.props.onConsoleOptionsOpen()
     this.setState({
@@ -82,6 +91,14 @@ class VmDetail extends Component {
     e.preventDefault()
   }
 
+  nicSettings (e) {
+    this.setState({
+      openNicSettings: !this.state.openNicSettings,
+    })
+
+    e.preventDefault()
+  }
+
   handleIconChange (e) {
     const that = this
     const reader = new FileReader()
@@ -134,23 +151,51 @@ class VmDetail extends Component {
     }
     const icon = icons.get(iconId)
     const disks = vm.get('disks')
+    const nics = vm.get('nics')
     const osName = getOsHumanName(vm.getIn(['os', 'type']))
     const cluster = Selectors.getClusterById(vm.getIn(['cluster', 'id']))
     const template = Selectors.getTemplateById(vm.getIn(['template', 'id']))
 
-    const disksElement = (<VmDisks disks={disks} open={this.state.renderDisks} />)
+    const disksElement = (<VmDisks disks={disks} vmId={vm.get('id')} edit={this.state.editDisks} />)
+
+    const diskEditAllowed = !isPool && !vm.getIn(['pool', 'id'])
+    const pencilIcon = (<i className={`pficon pficon-edit`} />)
+    const disksEditPencil = (
+      <small className={style.editPencilLink}>
+        {
+          diskEditAllowed
+          ? (<a href='#' onClick={this.editDisks} id={`${idPrefix}-edit-disks`}>{pencilIcon}</a>)
+          : (<FieldHelp content={msg.notEditableForPoolsOrPoolVms()} text={pencilIcon} />)
+        }
+      </small>)
 
     let optionsJS = options.hasIn(['options', 'consoleOptions', vm.get('id')]) ? options.getIn(['options', 'consoleOptions', vm.get('id')]).toJS() : {}
 
     const consoleOptionsShowHide = (
-      <small>
+      <small className={style.editPencilLink}>
         <a href='#' onClick={this.consoleSettings} id={`${idPrefix}-consoleoptions-showhide`}>
-          <i className={`pficon pficon-edit`} />&nbsp;
+          <i className={`pficon pficon-edit`} />
         </a>
       </small>)
 
+    const notPoolOrPoolVm = !isPool && vm.getIn(['pool', 'id']) === undefined
+    const nicOptionsShowHide = notPoolOrPoolVm ? (
+      <small>
+        <a href='#' onClick={this.nicSettings} id={`${idPrefix}-nicoptions-showhide`}>
+          {pencilIcon}
+        </a>
+      </small>
+    ) : (
+      <small>
+        <FieldHelp content={msg.notEditableForPoolsOrPoolVms()} text={pencilIcon} />
+      </small>
+    )
+
     const hasDisks = disks.size > 0
-    const noDisks = hasDisks || (<small>{msg.noDisks()}</small>)
+    const noDisks = hasDisks || (<small>{msg.noDisks()} &nbsp;</small>)
+
+    const hasNics = nics.size > 0
+    const noNics = hasNics || (<dd><small>{msg.noNics()}</small></dd>)
 
     const consolesHelp = (
       <div>
@@ -177,7 +222,7 @@ class VmDetail extends Component {
     }
 
     return (
-      <div className={style['main-container']}>
+      <div className={style['main-container']} data-thisIsVmDetail>
         <VmsListNavigation selectedVm={vm} expanded={this.state.vmsNavigationExpanded} toggleExpansion={this.toggleVmsNavExpansion} />
         <div className={style['vm-detail-main']}>
           <div className={this.state.vmsNavigationExpanded ? style['vms-nav-expanded'] : style['vms-nav-collapsed']}>
@@ -246,20 +291,28 @@ class VmDetail extends Component {
                 <dl className={sharedStyle['vm-properties']}>
                   <dt><span className='pficon pficon-screen' />
                     &nbsp;
-                    <FieldHelp content={consolesHelp} text={msg.console()} />
-                    &nbsp;
+                    <FieldHelp content={consolesHelp} text={msg.console()} popoverWidth='220px' />
                     {consoleOptionsShowHide}
                   </dt>
                   <VmConsoles vm={vm} onConsole={onConsole} onRDP={onRDP} usbFilter={config.get('usbFilter')} />
                   <ConsoleOptions smartcardOptionEnable={vm.getIn(['display', 'smartcardEnabled'])} options={optionsJS} onSave={onConsoleOptionsSave} open={this.state.openConsoleSettings} />
 
-                  <dt><span className='fa fa-database' />
+                  <dt>
+                    <span className='fa fa-database' />
                     &nbsp;
                     <FieldHelp content={msg.storageConnectedToVm()} text={msg.disks()} />
-                    &nbsp;
+                    {disksEditPencil}
                   </dt>
                   {noDisks}
                   {disksElement}
+                  <dt><span className='pficon pficon-container-node' />
+                    &nbsp;
+                    <FieldHelp content={msg.nicsTooltip()} text={msg.nic()} />
+                    &nbsp;
+                    {nicOptionsShowHide}
+                  </dt>
+                  {noNics}
+                  <VmNics nics={nics} vmId={vm.get('id')} showSettings={this.state.openNicSettings && notPoolOrPoolVm} />
                   <dt>
                     <FieldHelp content={msg.bootMenuTooltip()} text={msg.bootMenu()} />
                   </dt>
