@@ -40,6 +40,10 @@ export const messages = {
     message: 'unknown',
     description: 'followed by "version" to create "unknown version"',
   },
+  unknownDatacenter: {
+    message: 'unknown',
+    description: 'unknown datacenter',
+  },
   htmlUnsupportedOvirtVersionFoundButVersionAtLeastRequired: '<strong>Unsupported {version} {productName} version,</strong> found but version at least {requiredVersion} is required.',
   authorizationExpired: 'Authorization expired. The page is going to be reloaded to re-login.',
   useCtrlAltEnd: 'Use Ctrl+Alt+End',
@@ -49,6 +53,10 @@ export const messages = {
   consoleInUseContinue: 'Console in use, continue?',
   yes: 'Yes',
   cancel: 'Cancel',
+  newNic: {
+    message: 'New',
+    description: 'New NIC',
+  },
   save: 'Save',
   preserveDisks: 'Preserve disks',
   removeVmQustion: 'Remove the VM?',
@@ -94,7 +102,7 @@ export const messages = {
   definedMemory: 'Defined Memory',
   totalMemoryVmWillBeEquippedWith: 'Total memory the virtual machine will be equipped with.',
   lowOVirtVersion: 'SSH keys can not be managed with recent oVirt <strong>{apiVersion}</strong> version. Please upgrade oVirt to <strong>4.2</strong> or higher.',
-  publicSSHKey: 'Your public SSH key.',
+  publicSSHKey: 'Specify public key for access to guest serial console via SSH authentication.',
   SSHKey: 'SSH Key',
   cpus: 'CPUs',
   totalCountOfVirtualProcessorsVmWillBeEquippedWith: 'Total count of virtual processors the virtual machine will be equipped with.',
@@ -174,6 +182,7 @@ export const messages = {
     message: 'Unassigned',
     description: 'Error when obtaining virtual machine status. One of states of a virtual machine. Other are e.g. Up, Down, Powering-Up',
   },
+  clickForHelp: 'Click for help',
   hostConsole: {
     message: 'Host Console',
     description: 'Label of link to the Cockpit app',
@@ -209,6 +218,48 @@ export const messages = {
     message: 'Loading ...',
     description: 'Pending request to the server indicator label.',
   },
+  thisOperationCantBeUndone: 'This operation cannot be undone.',
+  areYouSureYouWantToDeleteDisk: 'Are you sure you want to delete disk {diskName}?',
+  delete: 'Delete',
+  confirmDelete: 'Confirm delete',
+  diskCapacity: 'Disk Capacity',
+  more: {
+    message: 'more',
+    description: 'more/less pair used to control collapsable long listing',
+  },
+  less: {
+    message: 'less',
+    description: 'more/less pair used to control collapsable long listing',
+  },
+  new: {
+    message: 'New',
+    description: 'New disk',
+  },
+  ok: 'OK',
+  createNewDisk: 'Create New Disk',
+  diskSizeHasToBeAPositiveInteger: 'Disk size has to be a positive integer.',
+  noActiveStorageDomainInDataCenter: 'There is no active data storage domain in data center "{dataCenterName}"',
+  alias: {
+    message: 'Alias',
+    description: 'In sense of "human friendly name"',
+  },
+  storageDomain: {
+    message: 'Storage domain',
+    description: 'An entity in the system where disks of virtual machines are stored. Abstraction of external file/block storages.',
+  },
+  size: {
+    message: 'Size',
+    description: '... of disk of virtual machine',
+  },
+  errorWhileCreatingNewDisk: 'Error while creating new disk:',
+  notEditableForPoolsOrPoolVms: 'Not editable for Pools or pool VMs.',
+  nic: 'Network interfaces',
+  noNics: 'no NICs',
+  addNewNic: 'Add new NIC',
+  vnicProfile: 'VNIC Profile',
+  areYouSureYouWantToDeleteNic: 'Are you sure you want to delete NIC {nicName}?',
+  nicsTooltip: 'Connected VM network interfaces.',
+  network: 'Network',
 }
 
 export type MessageIdType = $Keys<typeof messages>
