@@ -1,5 +1,4 @@
-import { saveToLocalStorage, loadFromLocalStorage } from './storage'
-
+import { saveToLocalStorage, loadFromLocalStorage, removeFromLocalStorage } from './storage'
 import { logDebug } from './helpers'
 
 export default {
@@ -35,6 +34,14 @@ export default {
     saveToLocalStorage(`consoleOptions.${vmId}`, JSON.stringify(options))
   },
 
+  clearAutoConnect () {
+    let vmId = loadFromLocalStorage('autoConnect')
+    if (vmId) {
+      saveToLocalStorage('autoConnect', '')
+      removeFromLocalStorage(`consoleOptions.${vmId}`)
+    }
+  },
+
   loadAutoConnectOption () {
     return loadFromLocalStorage('autoConnect')
   },
